program read_cps2
  !
  ! READ_CPS   reads file avghrs.dat and writes out hours and populations
  !            the year desired (iyear) and characteristics desired.  
  !            The file cps.dat has 2,451,246 records (rows).  The list 
  !            of variables and their lengths is given in cps.sas.

  ! Ellen McGrattan, 8-30-05
  ! Revised, ERM, 5-28-09
 
  implicit none
  integer, parameter     :: m=1000
  integer                :: year,perwt,blswt,age,sex,marst,popstat,educrec,  &
                            empstat,labforce,occ,ind,classwkr,occly,indly,   &
                            classswly,hrswork,uhrswork,fullpart,firmsize,    &
                            paidhour,hourwage,inctot,incwage,i,j,iyr,iy,     &
                            locc,inocclist,lind,inindlist,occcase,indcase
  integer, dimension(m)  :: occlist,indlist
  integer, dimension(1)  :: indlist0,occlist0
  integer, dimension(13) :: indlist1
  integer, dimension(68) :: indlist2
  integer, dimension(5)  :: occlist1
  integer, dimension(10) :: occlist2
  integer, dimension(14) :: occlist3
  integer, dimension(19) :: occlist4
  integer, dimension(18) :: occlist5
  integer, dimension(197):: occlist6
  integer, dimension(467):: occlist7
  real, dimension(16)    :: popall,popsub1,popsub2,popsub3,                  &
                            hrsall,hrssub1,hrssub2,hrssub3
  real                   :: fac
  
  open(unit=5, file='/mnt/disk2/cps/avghrs/avghrs.dat')
  open(unit=7, file='case.inp')
  open(unit=8, file='sweat2.out')
  open(unit=9, file='list.out')

  read(7,*) occcase,indcase 
  write(*,'(1x,a26,i2)') 'The occupational list is: ',occcase
  write(*,'(1x,a26,i2)') 'The industry list is:     ',indcase
  write(*,*) 'Run sweat.m in Matlab to see hours contributions'
  write(*,*) 
  ! 
  ! Filters using industry restrictions:
  !    1. IT-producing industries based on Digital Economy 2003 Table A-1.1
  !    2. IT-producing and IT-using list based Oliner et al.
  !
  indlist0  = (/ -1 /)
  indlist1  = (/ 321,322,331,341,342,371,440,441,442,510,  &
                 732,741,752 /)
  indlist2  = (/  60,172,180,181,182,190,191,192,310,311,  &
                 312,320,321,322,331,332,340,341,342,350,  &
                 351,352,360,361,362,370,371,391,420,421,  &
                 422,440,441,442,500,501,502,510,511,512,  &
                 521,522,530,531,532,540,541,542,550,551,  &
                 552,560,561,562,571,700,701,702,710,711,  &
                 730,732,741,752,841,891,892,893 /)
  !
  ! Filters using occupation restrictions
  !    1. High skilled IT occupations based on Digital Economy 2003 Box 2.1
  !    2. Most frequent for industry list 1 (frequency exceeding 2%)
  !    3. Expand (1) to include certain managerial professions
  !    4. Expand (2) to include certain managerial professions
  !    5. Occupations used in first draft of paper
  !    6. Occupations 3 to 199 (which is category 1 in SCF)
  !    7. Occupations 3 to 469 (which is categories 1 and 2 in SCF)
  !
  occlist0  = (/ -1 /)
  occlist1  = (/  22, 55, 64,213,229 /)
  occlist2  = (/  13, 22, 23, 55, 64,185,213,229,257,259 /)
  occlist3  = (/   4,  7, 13, 14, 15, 21, 22, 26, 34, 37, &
                  55, 64,213,229 /)
  occlist4  = (/   4,  7, 13, 14, 15, 21, 22, 23, 26, 34, &
                  37, 55, 64,185,213,229,257,259,529 /)
  occlist5  = (/   4,  7,  9, 13, 14, 15, 18, 21, 22, 23, &
                  24, 25, 34, 37, 64, 65,229,255 /)

  do i=1,197
    occlist6(i)     = i+2
  enddo
  do i=1,467
    occlist7(i)     = i+2
  enddo

  if (indcase==0) then
    lind            = 1
    indlist(1:lind) = indlist0
  endif 
  if (indcase==1) then
    lind            = 13
    indlist(1:lind) = indlist1
  endif 
  if (indcase==2) then
    lind            = 68
    indlist(1:lind) = indlist2
  endif
  if (occcase==0) then
    locc            = 1
    occlist(1:locc) = occlist0
  endif 
  if (occcase==1) then
    locc            = 5 
    occlist(1:locc) = occlist1
  endif 
  if (occcase==2) then
    locc            = 10
    occlist(1:locc) = occlist2
  endif 
  if (occcase==3) then
    locc            = 14
    occlist(1:locc) = occlist3
  endif 
  if (occcase==4) then
    locc            = 19
    occlist(1:locc) = occlist4
  endif 
  if (occcase==5) then
    locc            = 18
    occlist(1:locc) = occlist5
  endif 
  if (occcase==6) then
    locc            = 197
    occlist(1:locc) = occlist6
  endif 
  if (occcase==7) then
    locc            = 467
    occlist(1:locc) = occlist7
  endif 

  popall   = 0.
  popsub1  = 0.
  popsub2  = 0.
  popsub3  = 0.
  hrsall   = 0.
  hrssub1  = 0.
  hrssub2  = 0.
  hrssub3  = 0.

  do i=1,2451246
    read(5,'(I4,2I8,I2,3I1,2I2,I1,I3,I4,I2,I3,I4,3I2,3I1,I4,2I6)')       &
           year,perwt,blswt,age,sex,marst,popstat,educrec,               &
           empstat,labforce,occ,ind,classwkr,occly,indly,                &
           classswly,hrswork,uhrswork,fullpart,firmsize,                 &
           paidhour,hourwage,inctot,incwage

    if ((year>=1992).and.(year<=2002)) then

      iy        = year-1991
      inocclist = 0
      inindlist = 0
      do j=1,locc
        if (occ==occlist(j)) inocclist = 1
      enddo
      do j=1,lind
        if (ind==indlist(j)) inindlist = 1
      enddo

      ! Write out characteristics for those on the industry list
      !
      !if (inindlist==1) write(9,'(7i8)') year,inocclist,inindlist,       &
      !        occ,ind,perwt,educrec
      !
      ! Write out characteristics for those on the occupation list
      !
      if (inocclist==1) write(9,'(7i8)') year,inocclist,inindlist,       &
              occ,ind,perwt,educrec

      ! Working age population is 16-64
      !
      if ((age>=16).and.(age<=64)) then
        popall(iy) = popall(iy)+float(perwt)
        hrsall(iy) = hrsall(iy)+float(hrswork*perwt)
        !
        ! Subgroup 1 are those not working last week 
        !
        if (empstat/=10) then

          popsub1(iy) = popsub1(iy)+float(perwt)
          hrssub1(iy) = hrssub1(iy)+float(hrswork*perwt)

        else
          !
          ! Of those working last week ...
          !
          !   Subgroup 2 are 
          !     * Educated and 
          !     * Self-employed or privately employed and
          !     * In occlist or indlist
          !
          if ((educrec>=8).and.((classwkr==13).or.(classwkr==14).or.          &
              (classwkr==22)).and.((inocclist==1).or.(inindlist==1))) then
            popsub2(iy) = popsub2(iy)+float(perwt)
            hrssub2(iy) = hrssub2(iy)+float(hrswork*perwt)
          else
            !
            !   Subgroup 3 are the residual group
            !
            popsub3(iy) = popsub3(iy)+float(perwt)
            hrssub3(iy) = hrssub3(iy)+float(hrswork*perwt)
          endif
        endif
      endif
    endif
    enddo
    write(8,*) '% Columns:                                                 '
    write(8,*) '%   1.    Year                                             '
    write(8,*) '%   2-5.  Weekly Hours for total and 3 groups              '
    write(8,*) '%   6-9.  Populations for total and 3 groups               '
    write(8,*) '%  10-13. Weekly hours per capita for total and 3 groups   '
    write(8,*) '%               '
    write(8,*) '%  where Ages    = 16-64                                   ' 
    write(8,*) '%        Group 1 = not working last week                   '
    write(8,*) '%        Group 2 = educated self-employed+private employees'
    write(8,*) '%                  in certain occupations/industries       '
    write(8,*) '%        Group 3 = all others working                      '
    write(8,*) '%               '
    iyr = 1992
    fac = 100000000.0
    do j=1,11
      write(8,'(1X,I4,4(1X,F8.1),2X,4(1X,F7.1),2X,4(1X,F5.2)')               &
        iyr,hrsall(j)/fac,hrssub1(j)/fac,hrssub2(j)/fac,hrssub3(j)/fac,      &
            popall(j)/fac,popsub1(j)/fac,popsub2(j)/fac,popsub3(j)/fac,      &
            hrsall(j)/popall(j),hrssub1(j)/popall(j),hrssub2(j)/popall(j),   &
            hrssub3(j)/popall(j)
      iyr = iyr+1
    enddo

end program read_cps2
